@@ -6,8 +6,15 @@ import os.path
 
 # needs_sphinx = '1.0'
 
-extensions = ['sphinx.ext.intersphinx', 'sphinx_issues']
-
+extensions = [
+    "sphinx.ext.ifconfig",
+    "sphinx.ext.intersphinx",
+    "sphinx.ext.napoleon",
+    "sphinx.ext.autodoc",
+    "sphinx_autodoc_typehints",
+    "sphinxcontrib.plantuml",
+    "sphinx_issues",
+]
 templates_path = ['_templates']
 source_suffix = '.rst'
 
@@ -57,6 +64,7 @@ rst_epilog = '''
 .. _tzlocal: https://pypi.org/project/tzlocal/
 .. _requests-file: https://github.com/dashea/requests-file
 .. _Plex: https://www.plex.tv/
+.. _portalocker: https://portalocker.readthedocs.io
 
 .. |project| replace:: {project}
 .. |project_bold| replace:: **{project}**
@@ -64,7 +72,7 @@ rst_epilog = '''
 
 # Intersphinx
 
-intersphinx_mapping = {'python': ('https://docs.python.org/3.6', None)}
+intersphinx_mapping = {'python': ('https://docs.python.org/3.7', None)}
 
 # HTML options
 
@@ -94,6 +102,22 @@ man_pages = [
      [author],
      5),
 ]
+man_show_urls = True
 
 # issues
 issues_github_path = 'languitar/autosuspend'
+
+# napoleon
+napoleon_google_docstring = True
+napoleon_numpye_docstring = False
+napoleon_include_init_with_doc = True
+
+typehints_fully_qualified = True
+
+
+def setup(app):
+    app.add_config_value(
+        'is_preview',
+        os.environ.get('READTHEDOCS_VERSION', '') == 'latest',
+        'env',
+    )
