@@ -2,9 +2,7 @@ from autosuspend.checks import Check
 
 
 class TestCheck:
-
     class DummyCheck(Check):
-
         @classmethod
         def create(cls, name, config):
             pass
@@ -12,12 +10,12 @@ class TestCheck:
         def check(self):
             pass
 
-    def test_name(self):
-        name = 'test'
+    def test_name(self) -> None:
+        name = "test"
         assert self.DummyCheck(name).name == name
 
-    def test_name_default(self):
+    def test_name_default(self) -> None:
         assert self.DummyCheck().name is not None
 
-    def test_str(self):
-        assert isinstance(str(self.DummyCheck('test')), str)
+    def test_str(self) -> None:
+        assert isinstance(str(self.DummyCheck("test")), str)
